---
name: Bug report
about: Tell us what is broken

---

### Description
Describe your issue here.

### Environment
- Git commit hash, and specific ML model (if any)
- Docker version, if using
- Operating system

### Steps to reproduce
- step 1
- step 2
- ...

### Expected result
What did you expect to happen?

### Actual result
Describe the error message or unexpected result.

Don't forget to upload any relevant data if this is required to trigger the issue.
